summaryrefslogtreecommitdiffstats
path: root/src/user.h
diff options
context:
space:
mode:
authorThomas Groman <tgroman@nuegia.net>2020-09-21 15:08:56 -0700
committerThomas Groman <tgroman@nuegia.net>2020-09-21 15:08:56 -0700
commit4aa31001bae125293466d582c2ed1dca441c1103 (patch)
tree5a2bdfc6d6b0ea1f94c53e7c7108d7108940f8c5 /src/user.h
parenteffdcc9b1cf185f24e67d9e627a77d823bcfef8f (diff)
parentb7965d023cb68bce6d9495eb6afbc73206c1afef (diff)
downloadtwinkle-jackaudio.tar
twinkle-jackaudio.tar.gz
twinkle-jackaudio.tar.lz
twinkle-jackaudio.tar.xz
twinkle-jackaudio.zip
Merge branch 'master' into jackaudiojackaudio
Diffstat (limited to 'src/user.h')
-rw-r--r--src/user.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/user.h b/src/user.h
index 93921c4..bbd33fa 100644
--- a/src/user.h
+++ b/src/user.h
@@ -487,10 +487,10 @@ private:
bool zrtp_send_if_supported;
// MWI
- // Indicate if MWI is sollicited or unsollicited.
- // RFC 3842 specifies that MWI must be sollicited (SUBSCRIBE).
- // Asterisk however only supported non-standard unsollicited MWI.
- bool mwi_sollicited;
+ // Indicate if MWI is solicited or unsolicited.
+ // RFC 3842 specifies that MWI must be solicited (SUBSCRIBE).
+ // Asterisk however only supported non-standard unsolicited MWI.
+ bool mwi_solicited;
// User name for subscribing to the mailbox
string mwi_user;
@@ -659,7 +659,7 @@ public:
bool get_zrtp_goclear_warning(void) const;
bool get_zrtp_sdp(void) const;
bool get_zrtp_send_if_supported(void) const;
- bool get_mwi_sollicited(void) const;
+ bool get_mwi_solicited(void) const;
string get_mwi_user(void) const;
t_url get_mwi_server(void) const;
bool get_mwi_via_proxy(void) const;
@@ -778,7 +778,7 @@ public:
void set_zrtp_goclear_warning(bool b);
void set_zrtp_sdp(bool b);
void set_zrtp_send_if_supported(bool b);
- void set_mwi_sollicited(bool b);
+ void set_mwi_solicited(bool b);
void set_mwi_user(const string &user);
void set_mwi_server(const t_url &url);
void set_mwi_via_proxy(bool b);